==> jc-1.4.0.tar.gz: polyglot/types/TableResolver.h <==
// public class polyglot.types.TableResolver

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class eec1a4cebd785b9d polyglot_types_ClassResolver
// @dep_class 4fb97851ac3ef2dd polyglot_types_TableResolver

// header file dependencies
// @dep_header polyglot_types_ClassResolver

#include "polyglot/types/ClassResolver.h"

#ifndef _JC_polyglot_types_TableResolver_H_
#define _JC_polyglot_types_TableResolver_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Map$object;
struct _jc_polyglot_types_Named$object;

// Typedefs
typedef struct _jc_polyglot_types_TableResolver$sub_refs	_jc_polyglot_types_TableResolver$sub_refs;
typedef struct _jc_polyglot_types_TableResolver$sub_nonrefs	_jc_polyglot_types_TableResolver$sub_nonrefs;
typedef struct _jc_polyglot_types_TableResolver$refs	_jc_polyglot_types_TableResolver$refs;
typedef struct _jc_polyglot_types_TableResolver$nonrefs	_jc_polyglot_types_TableResolver$nonrefs;
typedef struct _jc_polyglot_types_TableResolver$object	_jc_polyglot_types_TableResolver$object;

typedef struct _jc_polyglot_types_TableResolver$fields_struct	_jc_polyglot_types_TableResolver$fields_struct;
typedef const struct _jc_polyglot_types_TableResolver$vmethods	_jc_polyglot_types_TableResolver$vmethods;
typedef const struct _jc_polyglot_types_TableResolver$vtable	_jc_polyglot_types_TableResolver$vtable;
typedef const struct _jc_polyglot_types_TableResolver$vtype	_jc_polyglot_types_TableResolver$vtype;

// Class fields structure
struct _jc_polyglot_types_TableResolver$fields_struct {
	struct _jc_object	*TOPICS;
};
extern _jc_polyglot_types_TableResolver$fields_struct _jc_polyglot_types_TableResolver$class_fields;

// Constructors
extern void _jc_polyglot_types_TableResolver$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_types_TableResolver$object *);

// Virtual methods
extern void _jc_polyglot_types_TableResolver$method$addNamed$f1a30b80474eacc9(_jc_env *, struct _jc_polyglot_types_TableResolver$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern void _jc_polyglot_types_TableResolver$method$addNamed$f8c7b86f74362f53(_jc_env *, struct _jc_polyglot_types_TableResolver$object *, struct _jc_object *);
extern struct _jc_object *_jc_polyglot_types_TableResolver$method$find$6acc62ea1c707b3c(_jc_env *, struct _jc_polyglot_types_TableResolver$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_types_TableResolver$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_types_TableResolver$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_TableResolver$method_info$addNamed$f1a30b80474eacc9;
extern _jc_method _jc_polyglot_types_TableResolver$method_info$addNamed$f8c7b86f74362f53;
extern _jc_method _jc_polyglot_types_TableResolver$method_info$find$6acc62ea1c707b3c;
extern _jc_method _jc_polyglot_types_TableResolver$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_polyglot_types_TableResolver$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_polyglot_types_TableResolver$vmethods {
	void	(*addNamed$f1a30b80474eacc9)(_jc_env *, struct _jc_polyglot_types_TableResolver$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
	void	(*addNamed$f8c7b86f74362f53)(_jc_env *, struct _jc_polyglot_types_TableResolver$object *, struct _jc_object *);
	struct _jc_object	*(*find$6acc62ea1c707b3c)(_jc_env *, struct _jc_polyglot_types_TableResolver$object *, struct _jc_java_lang_String$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_types_TableResolver$object *);
};

// Vtable
struct _jc_polyglot_types_TableResolver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_ClassResolver$vmethods	polyglot_types_ClassResolver;
	_jc_polyglot_types_TableResolver$vmethods	polyglot_types_TableResolver;
};

// Vtype
struct _jc_polyglot_types_TableResolver$vtype {
	_jc_type			type;
	_jc_polyglot_types_TableResolver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_TableResolver$sub_refs {
	struct _jc_object	*table;
};

// Reference instance fields (object)
struct _jc_polyglot_types_TableResolver$refs {
    _jc_polyglot_types_TableResolver$sub_refs	polyglot_types_TableResolver;
    _jc_polyglot_types_ClassResolver$sub_refs	polyglot_types_ClassResolver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_TableResolver$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_TableResolver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_ClassResolver$sub_nonrefs	polyglot_types_ClassResolver;
    _jc_polyglot_types_TableResolver$sub_nonrefs	polyglot_types_TableResolver;
};

// Object instance structure
struct _jc_polyglot_types_TableResolver$object {
	_jc_polyglot_types_TableResolver$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_TableResolver$vtype	*vtype;
	_jc_polyglot_types_TableResolver$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_TableResolver$vtype _jc_polyglot_types_TableResolver$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_TableResolver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_TableResolver$class_object;

#endif	/* _JC_polyglot_types_TableResolver_H_ */

==> jc-1.4.6.tar.gz: polyglot/types/TableResolver.h <==
// public class polyglot.types.TableResolver

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class eec1a4cebd785b9d polyglot_types_ClassResolver
// @dep_class 4fb97851ac3ef2dd polyglot_types_TableResolver

// header file dependencies
// @dep_header polyglot_types_ClassResolver

#include "polyglot/types/ClassResolver.h"

#ifndef _JC_polyglot_types_TableResolver_H_
#define _JC_polyglot_types_TableResolver_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Map$object;
struct _jc_polyglot_types_Named$object;

// Typedefs
typedef struct _jc_polyglot_types_TableResolver$sub_refs	_jc_polyglot_types_TableResolver$sub_refs;
typedef struct _jc_polyglot_types_TableResolver$sub_nonrefs	_jc_polyglot_types_TableResolver$sub_nonrefs;
typedef struct _jc_polyglot_types_TableResolver$refs	_jc_polyglot_types_TableResolver$refs;
typedef struct _jc_polyglot_types_TableResolver$nonrefs	_jc_polyglot_types_TableResolver$nonrefs;
typedef struct _jc_polyglot_types_TableResolver$object	_jc_polyglot_types_TableResolver$object;

typedef struct _jc_polyglot_types_TableResolver$fields_struct	_jc_polyglot_types_TableResolver$fields_struct;
typedef const struct _jc_polyglot_types_TableResolver$vmethods	_jc_polyglot_types_TableResolver$vmethods;
typedef const struct _jc_polyglot_types_TableResolver$vtable	_jc_polyglot_types_TableResolver$vtable;
typedef const struct _jc_polyglot_types_TableResolver$vtype	_jc_polyglot_types_TableResolver$vtype;

// Class fields structure
struct _jc_polyglot_types_TableResolver$fields_struct {
	struct _jc_object	*TOPICS;
};
extern _jc_polyglot_types_TableResolver$fields_struct _jc_polyglot_types_TableResolver$class_fields;

// Constructors
extern void _jc_polyglot_types_TableResolver$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_types_TableResolver$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_polyglot_types_TableResolver$method$addNamed$f1a30b80474eacc9(_jc_env *, struct _jc_polyglot_types_TableResolver$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_types_TableResolver$method$addNamed$f8c7b86f74362f53(_jc_env *, struct _jc_polyglot_types_TableResolver$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_types_TableResolver$method$find$6acc62ea1c707b3c(_jc_env *, struct _jc_polyglot_types_TableResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_types_TableResolver$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_types_TableResolver$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_TableResolver$method_info$addNamed$f1a30b80474eacc9;
extern _jc_method _jc_polyglot_types_TableResolver$method_info$addNamed$f8c7b86f74362f53;
extern _jc_method _jc_polyglot_types_TableResolver$method_info$find$6acc62ea1c707b3c;
extern _jc_method _jc_polyglot_types_TableResolver$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_polyglot_types_TableResolver$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_types_TableResolver$vmethods {
	void	(*addNamed$f1a30b80474eacc9)(_jc_env *, struct _jc_polyglot_types_TableResolver$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*addNamed$f8c7b86f74362f53)(_jc_env *, struct _jc_polyglot_types_TableResolver$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*find$6acc62ea1c707b3c)(_jc_env *, struct _jc_polyglot_types_TableResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_types_TableResolver$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_types_TableResolver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_ClassResolver$vmethods	polyglot_types_ClassResolver;
	_jc_polyglot_types_TableResolver$vmethods	polyglot_types_TableResolver;
};

// Vtype
struct _jc_polyglot_types_TableResolver$vtype {
	_jc_type			type;
	_jc_polyglot_types_TableResolver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_TableResolver$sub_refs {
	struct _jc_object	*table;
};

// Reference instance fields (object)
struct _jc_polyglot_types_TableResolver$refs {
    _jc_polyglot_types_TableResolver$sub_refs	polyglot_types_TableResolver;
    _jc_polyglot_types_ClassResolver$sub_refs	polyglot_types_ClassResolver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_TableResolver$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_TableResolver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_ClassResolver$sub_nonrefs	polyglot_types_ClassResolver;
    _jc_polyglot_types_TableResolver$sub_nonrefs	polyglot_types_TableResolver;
};

// Object instance structure
struct _jc_polyglot_types_TableResolver$object {
	_jc_polyglot_types_TableResolver$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_TableResolver$vtype	*vtype;
	_jc_polyglot_types_TableResolver$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_TableResolver$vtype _jc_polyglot_types_TableResolver$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_TableResolver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_TableResolver$class_object;

#endif	/* _JC_polyglot_types_TableResolver_H_ */
